==> one_target_mobile_sdk-0.0.7.tar.gz: example/lib/screens/tracking/advancedTracking/search_flight_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/constant.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/detail_flight_screen.dart';

class SearchFlightScreen extends StatefulWidget {
  const SearchFlightScreen({Key? key}) : super(key: key);

  @override
  State<SearchFlightScreen> createState() => _SearchFlightScreenState();
}

class _SearchFlightScreenState extends State<SearchFlightScreen> {
  @override
  void initState() {
    super.initState();
    _setupTracking();
  }

  void _setupTracking() {
    //chọn môi trường để tracking, nếu set true thì sẽ tracking ở dev, false sẽ tracking ở prod.
    //Riêng đối với ios chỉ thực hiện tracking ở dev. Sẽ sớm bổ sung thêm prod ở next release.
    bool isEnvironmentDev = true;
    //isShowLog dùng để hiển thị log của sdk
    bool isShowLog = false;
    Analytics.setupTracking(
      isEnvironmentDev,
      workSpaceId,
      isShowLog: isShowLog,
    ).then((isSetupSuccess) {
      Utils.log("_setupTracking isSetupSuccess $isSetupSuccess");
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: Container(
          padding: const EdgeInsets.all(16.0),
          child: ListView(
            physics: const BouncingScrollPhysics(),
            children: [
              const SizedBox(height: 16.0),
              Align(
                alignment: Alignment.center,
                child: Utils.getText(
                  "Tìm chuyến bay",
                  32,
                  FontWeight.w500,
                  Colors.black,
                ),
              ),
              const SizedBox(height: 32.0),
              _buildRouterView(
                "Ho Chi Minh",
                () {},
                "02/08/2022",
                () {},
              ),
              const SizedBox(height: 16.0),
              _buildRouterView(
                "Ha Noi",
                () {},
                "03/09/2022",
                () {},
              ),
              const SizedBox(height: 16.0),
              const SizedBox(height: 16.0),
              Utils.getButton(
                "Tìm chuyến bay",
                16.0,
                Colors.white,
                Colors.deepPurple,
                null,
                () {
                  Get.to(() => const DetailFlightScreen());
                },
              ),
            ],
          ),
        ),
      ),
    );
  }

  Widget _buildRouterView(
    String text1,
    VoidCallback? onPressed1,
    String text2,
    VoidCallback? onPressed2,
  ) {
    return Row(
      children: [
        Flexible(
          flex: 5,
          child: Utils.getButton(
            text1,
            16.0,
            Colors.black,
            Colors.white,
            const Icon(Icons.unfold_more),
            onPressed1,
          ),
        ),
        const SizedBox(width: 16.0),
        Flexible(
          flex: 3,
          child: Utils.getButton(
            text2,
            16.0,
            Colors.black,
            Colors.white,
            null,
            onPressed2,
          ),
        ),
      ],
    );
  }
}

==> one_target_mobile_sdk-0.0.10.tar.gz: example/lib/screens/tracking/advancedTracking/search_flight_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/constant.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/detail_flight_screen.dart';

class SearchFlightScreen extends StatefulWidget {
  const SearchFlightScreen({Key? key}) : super(key: key);

  @override
  State<SearchFlightScreen> createState() => _SearchFlightScreenState();
}

class _SearchFlightScreenState extends State<SearchFlightScreen> {
  @override
  void initState() {
    super.initState();
    _setupTracking();
  }

  void _setupTracking() {
    G1SDK
        .setupSDK(
      G1SDK.ENV_DEV,
      Constant.getWorkSpaceId(),
      isShowLog: true,
    )
        .then((isSetupSuccess) {
      Utils.log("_setupTracking isSetupSuccess $isSetupSuccess");
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: Container(
          padding: const EdgeInsets.all(16.0),
          child: ListView(
            physics: const BouncingScrollPhysics(),
            children: [
              const SizedBox(height: 16.0),
              Align(
                alignment: Alignment.center,
                child: Utils.getText(
                  "Tìm chuyến bay",
                  32,
                  FontWeight.w500,
                  Colors.black,
                ),
              ),
              const SizedBox(height: 32.0),
              _buildRouterView(
                "Ho Chi Minh",
                () {},
                "02/08/2022",
                () {},
              ),
              const SizedBox(height: 16.0),
              _buildRouterView(
                "Ha Noi",
                () {},
                "03/09/2022",
                () {},
              ),
              const SizedBox(height: 16.0),
              const SizedBox(height: 16.0),
              Utils.getButton(
                "Tìm chuyến bay",
                16.0,
                Colors.white,
                Colors.deepPurple,
                null,
                () {
                  Get.to(() => const DetailFlightScreen());
                },
              ),
            ],
          ),
        ),
      ),
    );
  }

  Widget _buildRouterView(
    String text1,
    VoidCallback? onPressed1,
    String text2,
    VoidCallback? onPressed2,
  ) {
    return Row(
      children: [
        Flexible(
          flex: 5,
          child: Utils.getButton(
            text1,
            16.0,
            Colors.black,
            Colors.white,
            const Icon(Icons.unfold_more),
            onPressed1,
          ),
        ),
        const SizedBox(width: 16.0),
        Flexible(
          flex: 3,
          child: Utils.getButton(
            text2,
            16.0,
            Colors.black,
            Colors.white,
            null,
            onPressed2,
          ),
        ),
      ],
    );
  }
}
